"""
Command to load fixtures for Resume Manager Core models.
"""

# Third-Party Imports.
from django.contrib.auth import get_user_model
from django.core.management import call_command
from django.core.management.base import BaseCommand

# Internal Imports.
from apps.Resume_Manager.resume_manager_core.models import (
    Resume,
    ResumeTheme,
    ResumeSection,
    # ResumeToSectionIntermediary,
    # DataSectionHeader,
    # DataItem,
    # DataKeyValue,
)
from workspace_core.settings.reusable_settings import ConsoleColors


class Command(BaseCommand):
    help = 'Load fixtures into database models for Resume Manager Core app.'

    def handle(self, *args, **kwargs):
        """
        The logic of the command.
        """
        print('{0}RESUME_MANAGER_CORE{1}: {2}Load Fixtures{3} command has been called.'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

        # Run fixture imports.
        self.populate_resume_themes()
        self.populate_resumes()
        self.populate_section_css()
        self.populate_resume_sections()

        # self.populate_resume_section_intermediaries()
        # self.populate_data_section_headers()
        # self.populate_data_section_items()

        print('{0}RESUME_MANAGER_CORE{1}: {2}Fixture Loading{3} complete.\n'.format(
            ConsoleColors.purple,
            ConsoleColors.reset,
            ConsoleColors.blue,
            ConsoleColors.reset,
        ))

    def populate_resume_themes(self):
        """
        Loads fixtures for ResumeTheme models.
        """
        call_command('loaddata', 'resume_manager/resume_themes.json')

    def populate_resumes(self):
        """
        Loads fixtures for Resume models.
        """
        call_command('loaddata', 'resume_manager/resumes.json')

    def populate_section_css(self):
        """
        Loads fixtures for SectionCss models.
        """
        call_command('loaddata', 'resume_manager/section_css.json')

    def populate_resume_sections(self):
        """
        Loads fixtures for ResumeSection models.
        """
        call_command('loaddata', 'resume_manager/resume_sections.json')

    def populate_resume_section_intermediaries(self):
        """
        Loads fixtures for ResumeToSectionIntermediary models.
        """

        # Get "example_user" to associate all example resumes with.
        example_user = get_user_model().objects.get(username='example_user')

        # Create an example resume for each theme.
        resume_themes = ResumeTheme.objects.filter(name__startswith='Blocky ')
        for resume_theme in resume_themes:

            # Create new example resume for theme.
            current_resume = Resume.objects.create(
                user=example_user,
                theme=resume_theme,
                name='Example {0} Resume'.format(resume_theme.name),
            )

            # Get resume section models.
            section_format__page = ResumeSection.objects.get(name='Page')
            section_format__row__minimal = ResumeSection.objects.get(name='Row: Minimal')
            section_format__row__full = ResumeSection.objects.get(name='Row: Full')
            section_format__row__one_fifth = ResumeSection.objects.get(name='Row: One-Fifth')
            section_format__row__three_fifths = ResumeSection.objects.get(name='Row: Three-Fifths')
            section_format__column__minimal = ResumeSection.objects.get(name='Column: Minimal')
            section_format__column__full = ResumeSection.objects.get(name='Column: Full')
            section_format__text__left = ResumeSection.objects.get(name='Text: Left-Align')
            section_format__text__center = ResumeSection.objects.get(name='Text: Center-Align')
            section_format__text__right = ResumeSection.objects.get(name='Text: Right-Align')
            section_format__style__full_color = ResumeSection.objects.get(name='Style: Full Color')

            # For each resume, create 4 pages to showcase different possible formats.
            page_1 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format__page,
            )
            page_2 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format__page,
            )
            page_3 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format__page,
            )
            page_4 = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                section_format=section_format__page,
            )

            # Create page 1 main subsections.
            # Page one is in standard <header, middle, footer> format.
            page_1_header = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format__row__one_fifth,
            )
            page_1_header_background = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header,
                section_format=section_format__style__full_color,
            )
            page_1_header_left = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_background,
                section_format=section_format__row__full,
            )
            page_1_header_name = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_left,
                section_format=section_format__text__left,
                title='Example User',
            )
            page_1_header_right = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_background,
                section_format=section_format__column__full,
            )
            page_1_header_profession = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_right,
                section_format=section_format__text__center
            )
            ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_profession,
                section_format=section_format__text__right,
                title='Software',
            )
            ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_header_profession,
                section_format=section_format__text__right,
                title='Engineer',
            )
            page_1_middle = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format__column__full,
            )
            page_1_middle_contact = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_middle,
                section_format=section_format__column__full,
                title='Contact Info',
            )
            page_1_middle_experience = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_middle,
                section_format=section_format__column__full,
                title='Experience',
            )
            page_1_middle_education = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_middle,
                section_format=section_format__column__full,
                title='Education',
            )
            page_1_footer = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1,
                section_format=section_format__row__one_fifth,
            )
            page_1_footer_background = ResumeToSectionIntermediary.objects.create(
                resume=current_resume,
                parent_section=page_1_footer,
                section_format=section_format__style__full_color,
            )

            # Create data for page 1.
            DataKeyValue.objects.create(
                resume_section=page_1_middle_contact,
                data_key='Phone',
                data_value='(123) 456-7890',
            )
            DataKeyValue.objects.create(
                resume_section=page_1_middle_contact,
                data_key='Email',
                data_value=example_user.email,
            )
            DataKeyValue.objects.create(
                resume_section=page_1_middle_contact,
                data_key='GitHub',
                data_value='idk.github.com/example_user',
            )
            DataItem.objects.create(
                resume_section=page_1_middle_experience,
                title_left='Generic Company - Software Engineer',
                title_right='2020 - Present',
                item='Nulla ut mollis ipsum. Fusce ultricies a lectus ac condimentum. Aliquam vitae iaculis nibh. Sed nec tortor ac arcu tincidunt vestibulum sit amet in neque.',
                show_bullet_point=False,
            )
            DataItem.objects.create(
                resume_section=page_1_middle_experience,
                item='Donec varius velit sed ultricies pellentesque. Ut pulvinar ut justo vel scelerisque. Vestibulum convallis nunc tellus, vitae elementum nibh interdum sed. Donec eget magna porta nisl pulvinar gravida id non risus.',
                show_bullet_point=False,
            )
            # DataItem.objects.create(
            #     resume_section=page_1_middle_experience,
            #     item='Nullam mollis odio tortor, sed interdum quam porttitor eu. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae; Etiam at nulla vulputate, imperdiet velit id, molestie sem. Aliquam tellus urna, laoreet id risus sed, ullamcorper ornare massa. Maecenas quis metus a eros rutrum lacinia. Nullam fermentum sit amet leo at viverra. Ut lobortis leo feugiat congue finibus. Ut vitae volutpat purus, sit amet maximus magna. Vestibulum bibendum, ex quis aliquet ultricies, quam dui ultrices arcu, eget laoreet nunc metus eget sapien. Maecenas dictum leo vitae risus vestibulum, ac posuere diam molestie. In hac habitasse platea dictumst. Etiam sapien ex, ullamcorper a hendrerit ac, luctus vitae metus. Mauris euismod leo vel diam efficitur varius.',
            #     show_bullet_point=False,
            # )
            DataItem.objects.create(
                resume_section=page_1_middle_experience,
                title_left='Generic Company - IT Support',
                title_right='2015 - 2020',
                item='Nunc eu purus id sapien pretium fringilla. Etiam eu mi lobortis, sollicitudin metus finibus, pellentesque nisi. Ut tempus convallis justo, ac euismod dui consequat vitae. Integer iaculis purus nec lorem facilisis aliquam.',
                show_bullet_point=False,
            )
            DataItem.objects.create(
                resume_section=page_1_middle_experience,
                item='Vestibulum sagittis dolor vitae ex interdum, at scelerisque orci sollicitudin. Proin urna libero, eleifend at ex vel, tempus auctor tellus. Phasellus posuere sit amet tortor et interdum. Morbi viverra vehicula sem, a lobortis neque tincidunt ut. Donec viverra vulputate metus. Sed quis tortor eget lorem tempor iaculis a eu mauris.',
                show_bullet_point=False,
            )
            # DataItem.objects.create(
            #     resume_section=page_1_middle_experience,
            #     item='Proin semper est sapien, eu pellentesque libero efficitur eget. Aliquam vel commodo felis. In id tortor libero. Nam diam ante, pulvinar eget orci sed, sagittis scelerisque odio. Praesent tristique sagittis enim, ac malesuada risus lobortis ut. Proin sit amet lacus sed diam commodo hendrerit convallis at lectus. Donec vestibulum orci enim, ut dignissim velit vehicula eget. Vivamus nunc dui, rutrum sit amet nunc vitae, placerat maximus eros. Nam elit augue, accumsan sit amet porta ac, congue vitae arcu. Mauris imperdiet placerat ante pharetra iaculis. Cras ut arcu pellentesque, gravida ipsum quis, porta velit.',
            #     show_bullet_point=False,
            # )

            # Create page 2 main subsections.
            # Mimics a full resume in single-page format.

    def populate_data_section_headers(self):
        """
        Loads fixtures for DataSectionHeader models.
        """
        # No fixtures yet.
        pass

    def populate_data_section_items(self):
        """
        Loads fixtures for DataSectionItem models.
        """
        # No fixtures yet.
        pass
